/*
 * ms5637.h
 *
 *  Created on: Jul 30, 2014
 *      Author: JMBrinkhus
 */

#include <stdio.h>
#include "xiic_l.h"


#ifndef MS5637_H_
#define MS5637_H_

// MS5637 Constants
#define MS5637_I2C_ADDR				(0x76)	// 1110_110x
#define MS5637_PROM_BASE_ADDR		(0xA0)
#define MS5637_CONV_DELAY_OSR_256	(1)		// Datasheet says  0.54ms is typical,  1ms to be safe
#define MS5637_CONV_DELAY_OSR_512	(2)		// Datasheet says  1.06ms is typical,  2ms to be safe
#define MS5637_CONV_DELAY_OSR_1024	(3)		// Datasheet says  2.08ms is typical,  3ms to be safe
#define MS5637_CONV_DELAY_OSR_2048	(5)		// Datasheet says  4.13ms is typical,  5ms to be safe
#define MS5637_CONV_DELAY_OSR_4096	(10)	// Datasheet says  8.22ms is typical, 10ms to be safe
#define MS5637_CONV_DELAY_OSR_8192	(20)	// Datasheet says 16.44ms is typical, 18ms to be safe
#define CRC_POLY					(0x131)	// CRC Polynomial: X^8 + X^5 + X^4 + 1

// MS5637 I2C Commands
#define MS5637_I2C_CMD_RESET				(0x1E)
#define MS5637_I2C_CMD_READ_PROM_BASE		(0xA2)
#define MS5637_I2C_CMD_CONVERT_D1_OSR_256	(0x40)
#define MS5637_I2C_CMD_CONVERT_D1_OSR_512	(0x42)
#define MS5637_I2C_CMD_CONVERT_D1_OSR_1024	(0x44)
#define MS5637_I2C_CMD_CONVERT_D1_OSR_2048	(0x46)
#define MS5637_I2C_CMD_CONVERT_D1_OSR_4096	(0x48)
#define MS5637_I2C_CMD_CONVERT_D1_OSR_8192	(0x4A)
#define MS5637_I2C_CMD_CONVERT_D2_OSR_256	(0x50)
#define MS5637_I2C_CMD_CONVERT_D2_OSR_512	(0x52)
#define MS5637_I2C_CMD_CONVERT_D2_OSR_1024	(0x54)
#define MS5637_I2C_CMD_CONVERT_D2_OSR_2048	(0x56)
#define MS5637_I2C_CMD_CONVERT_D2_OSR_4096	(0x58)
#define MS5637_I2C_CMD_CONVERT_D2_OSR_8192	(0x5A)
#define MS5637_I2C_CMD_READ_ADC				(0x00)

typedef enum ms5637_status{
	ms5637_status_ok = 0,
	ms5637_status_i2c_transfer_error = 1,
	ms5637_status_crc_error = 2
}ms5637_status;
typedef enum ms5637_resolution_osr{
	ms5637_resolution_osr_256  = 0,
	ms5637_resolution_osr_512  = 1,
	ms5637_resolution_osr_1024 = 2,
	ms5637_resolution_osr_2048 = 3,
	ms5637_resolution_osr_4096 = 4,
	ms5637_resolution_osr_8192 = 5
}ms5637_resolution_osr;

#endif /* MS5637_H_ */

// External variables
extern 	u32 					ms5637_axi_address;
extern 	u32	 					ms5637_prom_coeffs[7];
extern	ms5637_resolution_osr	ms5637_resolution;

// Function Declarations
void 			ms5637_init(u32 axi_address);
ms5637_status 	ms5637_reset(void);
ms5637_status 	ms5637_read_prom(void);
void 			ms5637_set_resolution(ms5637_resolution_osr res);
ms5637_status 	ms5637_read_temperature_and_pressure(float* temperature, float* pressure);
int CRC8(char*);
int CRC16(char*);
